# Pixi Tasks

*This page is auto-generated. Do not edit directly.*

DiracX uses [Pixi](https://pixi.dev/) as package manager
This page documents the available pixi tasks.

## Client Generation Tasks

- `generate-client`: Generate the API clients for diracx-client

## Default Tasks

- `description`: Run pre-commit hooks

## DiracX Tasks

- `pytest-diracx`: pytest
- `pytest-diracx-all-one-by-one`: No description
- `pytest-diracx-api`: Run the tests for diracx-api
- `pytest-diracx-cli`: Run the tests for diracx-cli
- `pytest-diracx-client`: Run the tests for diracx-client
- `pytest-diracx-core`: Run the tests for diracx-core
- `pytest-diracx-db`: Run the tests for diracx-db
- `pytest-diracx-logic`: Run the tests for diracx-logic
- `pytest-diracx-routers`: Run the tests for diracx-routers

## Documentation Tasks

- `mkdocs`: mkdocs serve
- `mkdocs-build`: mkdocs build --strict

## Gubbins Tasks

- `pytest-gubbins`: Run the tests for gubbins
- `pytest-gubbins-all-one-by-one`: Run all gubbins tests one by one
- `pytest-gubbins-api`: Run the tests for gubbins-api
- `pytest-gubbins-cli`: Run the tests for gubbins-cli
- `pytest-gubbins-client`: Run the tests for gubbins-client
- `pytest-gubbins-core`: Run the tests for gubbins-core
- `pytest-gubbins-db`: Run the tests for gubbins-db
- `pytest-gubbins-logic`: Run the tests for gubbins-logic
- `pytest-gubbins-routers`: Run the tests for gubbins-routers

## Pre-commit Tasks

- `pre-commit`: pre-commit

## Shellcheck Tasks

- `shellcheck`: Run shellcheck on all shell scripts

Generated by .github/workflows/generate_pixi_tasks_doc.py
